@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -39,12 +39,21 @@ except ImportError:
 # Module global variables
 # -----------------------------------------------------------------------------
 
-ROOT = dirname(realpath(__file__))
-BOKEHJSROOT = join(ROOT, 'bokehjs')
-BOKEHJSBUILD = join(BOKEHJSROOT, 'build')
-JS = join(BOKEHJSBUILD, 'js')
-SERVER = join(ROOT, 'bokeh/server')
-TSLIB = join(BOKEHJSROOT , 'node_modules/typescript/lib')
+MIN_PYTHON_VERSION = (3, 7)
+
+# state our runtime deps here, also used by meta.yaml (so KEEP the spaces)
+INSTALL_REQUIRES = [
+    'Jinja2 >=2.9',
+    'numpy >=1.11.3',
+    'packaging >=16.8',
+    'pillow >=7.1.0',
+    'PyYAML >=3.10',
+    'tornado >=5.1',
+    'typing_extensions >=3.10.0',
+]
+
+BUILD_JS = "--build-js"
+INSTALL_JS = "--install-js"
 
 # -----------------------------------------------------------------------------
 # Helpers for command line operations
@@ -66,14 +75,20 @@ def show_bokehjs(bokehjs_action, develop=False):
 
     '''
     print()
-    if develop:
-        print("Installed Bokeh for DEVELOPMENT:")
+
+    print("Installed Bokeh for DEVELOPMENT:" if develop else "Installed Bokeh:")
+
+    if bokehjs_action == "built":
+        kind = bright(yellow("NEWLY BUILT"))
+        loc = "bokehjs/build"
+    elif bokehjs_action == "installed":
+        kind = bright(yellow("PREVIOUSLY BUILT"))
+        loc = "bokehjs/build"
     else:
-        print("Installed Bokeh:")
-    if bokehjs_action in ['built', 'installed']:
-        print("  - using %s built BokehJS from bokehjs/build\n" % (bright(yellow("NEWLY")) if bokehjs_action=='built' else bright(yellow("PREVIOUSLY"))))
-    else:
-        print("  - using %s BokehJS, located in 'bokeh.server.static'\n" % bright(yellow("PACKAGED")))
+        kind = bright(yellow("PACKAGED"))
+        loc = "bokeh.server.static"
+    print(f"  - using {kind} BokehJS, from {loc}\n")
+
     print()
 
 def show_help(bokehjs_action):
@@ -88,7 +103,7 @@ def show_help(bokehjs_action):
 
     '''
     print()
-    if bokehjs_action in ['built', 'installed']:
+    if bokehjs_action in ('built', 'installed'):
         print("Bokeh-specific options available with 'install' or 'develop':")
         print()
         print("  --build-js          build and install a fresh BokehJS")
@@ -103,100 +118,95 @@ def show_help(bokehjs_action):
 # Other functions used directly by setup.py
 # -----------------------------------------------------------------------------
 
-def build_or_install_bokehjs():
+def build_or_install_bokehjs(is_packaged):
     ''' Build a new BokehJS (and install it) or install a previously build
     BokehJS.
 
     If no options ``--build-js`` or ``--install-js`` are detected, the
     user is prompted for what to do.
 
-    If ``--existing-js`` is detected, then this setup.py is being run from a
-    packaged sdist, no action is taken.
-
     Note that ``-build-js`` is only compatible with the following ``setup.py``
     commands: install, develop, sdist, egg_info, build
 
+    .. note:
+        If setup.py is being run from a packaged sdist, then no work is done.
+
     Returns:
         str : one of 'built', 'installed', 'packaged'
             How (or if) BokehJS was installed into the python source tree
 
     '''
 
-    # This happens when building from inside a published, pre-packaged sdist
-    # The --existing-js option is not otherwise documented
-    if '--existing-js' in sys.argv:
-        sys.argv.remove('--existing-js')
+    # If (re-)building from inside a published, pre-packaged sdist, then no
+    # need to do anything -- BokehJS is already built and inside the package
+    if is_packaged:
         return "packaged"
 
-    if '--build-js' not in sys.argv and '--install-js' not in sys.argv:
-        jsbuild = jsbuild_prompt()
+    if BUILD_JS not in sys.argv and INSTALL_JS not in sys.argv:
+        sys.argv.append(jsbuild_prompt())
 
-    elif '--build-js' in sys.argv:
-        jsbuild = True
-        sys.argv.remove('--build-js')
-
-    # must be "--install-js"
-    else:
-        jsbuild = False
-        sys.argv.remove('--install-js')
-
-    jsbuild_ok = ('install', 'develop', 'sdist', 'egg_info', 'build')
-    if jsbuild and not any(arg in sys.argv for arg in jsbuild_ok):
-        print("Error: Option '--build-js' only valid with 'install', 'develop', 'sdist', or 'build', exiting.")
-        sys.exit(1)
-
-    if jsbuild:
-        build_js()
-        install_js()
-        return "built"
-    else:
+    if INSTALL_JS in sys.argv:
+        sys.argv.remove(INSTALL_JS)
         install_js()
         return "installed"
 
+    # must be "--build-js"
+    sys.argv.remove(BUILD_JS)
+
+    jsbuild_ok = ('install', 'develop', 'sdist', 'bdist_wheel', 'egg_info', 'build')
+    if not any(arg in sys.argv for arg in jsbuild_ok):
+        print("Error: Option --build-js only valid with 'install', 'develop', 'sdist', 'bdist_wheel', or 'build', exiting.")
+        sys.exit(1)
+
+    build_js()
+    install_js()
+    return "built"
+
 def conda_rendering():
     return os.getenv("CONDA_BUILD_STATE" ,"junk") == "RENDER"
 
+def check_python():
+    if sys.version_info[:2] < MIN_PYTHON_VERSION:
+        raise RuntimeError("Bokeh requires Python >= " + ".".join(str(x) for x in MIN_PYTHON_VERSION))
 
-def check_building_sdist():
-    ''' Check for 'sdist' and ensure we always build or install BokehJS when
-    packaging
+def check_packaged():
+    ROOT = dirname(realpath(__file__))
+    return exists(join(ROOT, 'PKG-INFO'))
 
-    Source distributions do not ship with BokehJS source code, but must ship
-    with a pre-built BokehJS library. This function checks ``sys.argv`` to
-    ensure that ``--build-js`` or ``--install-js` is present.
+def check_building_dist():
+    ''' Check for 'sdist' or `bdist_wheel` and ensure we always build or install
+    BokehJS when packaging.
+
+    Source distributions (sdists) and wheels do not ship with BokehJS source
+    code, but  must ship with a pre-built BokehJS library. This function checks
+    ``sys.argv`` to ensure that ``--build-js`` or ``--install-js`` is present.
 
     Returns:
         None
 
     '''
-    if "sdist" in sys.argv:
-        if "--install-js" not in sys.argv and "--build-js" not in sys.argv:
-            print("Error: Option '--build-js' or '--install-js' must be present with 'sdist', exiting.")
+    for dist in ("sdist", "bdist_wheel"):
+        if dist in sys.argv and (INSTALL_JS not in sys.argv and BUILD_JS not in sys.argv):
+            print(f"Error: Option --build-js or --install-js must be present with {dist!r}, exiting.")
             sys.exit(1)
 
 def fixup_for_packaged():
-    ''' If we are installing FROM an sdist, then a pre-built BokehJS is
-    already installed in the python source tree.
+    ''' If we are installing or building FROM an sdist, then a pre-built
+    BokehJS is already installed in the python source tree.
 
     The command line options ``--build-js`` or ``--install-js`` are
     removed from ``sys.argv``, with a warning.
 
-    Also adds ``--existing-js`` to ``sys.argv`` to signal that BokehJS is
-    already packaged.
-
     Returns:
-        None
+        True if we are installing or building FROM and sdist, else False
 
     '''
-    if exists(join(ROOT, 'PKG-INFO')):
-        if "--build-js" in sys.argv or "--install-js" in sys.argv:
-            print(SDIST_BUILD_WARNING)
-            if "--build-js" in sys.argv:
-                sys.argv.remove('--build-js')
-            if "--install-js" in sys.argv:
-                sys.argv.remove('--install-js')
-        if "--existing-js" not in sys.argv:
-            sys.argv.append('--existing-js')
+    if BUILD_JS in sys.argv or INSTALL_JS in sys.argv:
+        print(SDIST_BUILD_WARNING)
+        if BUILD_JS in sys.argv:
+            sys.argv.remove(BUILD_JS)
+        if INSTALL_JS in sys.argv:
+            sys.argv.remove(INSTALL_JS)
 
 # -----------------------------------------------------------------------------
 # Helpers for operation in the bokehjs dir
@@ -206,14 +216,14 @@ def jsbuild_prompt():
     ''' Prompt users whether to build a new BokehJS or install an existing one.
 
     Returns:
-        bool : True, if a new build is requested, False otherwise
+        str
 
     '''
     print(BOKEHJS_BUILD_PROMPT)
-    mapping = {"1": True, "2": False}
+    mapping = {"1": BUILD_JS, "2": INSTALL_JS}
     value = input("Choice? ")  # lgtm [py/use-of-input]
     while value not in mapping:
-        print("Input '%s' not understood. Valid choices: 1, 2\n" % value)
+        print(f"Input {value!r} not understood. Valid choices: 1, 2\n")
         value = input("Choice? ")  # lgtm [py/use-of-input]
     return mapping[value]
 
@@ -235,7 +245,7 @@ def build_js():
     sys.stdout.flush()
     os.chdir('bokehjs')
 
-    cmd = ["node", "make", 'build', '--emit-error']
+    cmd = ["node", "make", "build"]
 
     t0 = time.time()
     try:
@@ -285,6 +295,12 @@ def build_js():
 
         print("  - bokeh-api.js          : %6.1f KB" % size("js", "bokeh-api.js"))
         print("  - bokeh-api.min.js      : %6.1f KB" % size("js", "bokeh-api.min.js"))
+
+        print("  - bokeh-gl.js           : %6.1f KB" % size("js", "bokeh-gl.js"))
+        print("  - bokeh-gl.min.js       : %6.1f KB" % size("js", "bokeh-gl.min.js"))
+
+        print("  - bokeh-mathjax.js      : %6.1f KB" % size("js", "bokeh-mathjax.js"))
+        print("  - bokeh-mathjax.min.js  : %6.1f KB" % size("js", "bokeh-mathjax.min.js"))
     except Exception as e:
         print(BUILD_SIZE_FAIL_MSG % e)
         sys.exit(1)
@@ -296,6 +312,13 @@ def install_js():
         None
 
     '''
+    ROOT = dirname(realpath(__file__))
+    BOKEHJSROOT = join(ROOT, 'bokehjs')
+    BOKEHJSBUILD = join(BOKEHJSROOT, 'build')
+    JS = join(BOKEHJSBUILD, 'js')
+    SERVER = join(ROOT, 'bokeh/server')
+    TSLIB = join(BOKEHJSROOT , 'node_modules/typescript/lib')
+
     target_jsdir = join(SERVER, 'static', 'js')
     target_tslibdir = join(SERVER, 'static', 'lib')
 
@@ -335,7 +358,7 @@ ERROR: Cannot install BokehJS: files missing in `./bokehjs/build`.
 
 
 Please build BokehJS by running setup.py with the `--build-js` option.
-  Dev Guide: https://docs.bokeh.org/en/latest/docs/dev_guide/setup.html.
+  Contributor Guide: https://docs.bokeh.org/en/latest/docs/dev_guide/setup.html.
 """
 
 BUILD_EXEC_FAIL_MSG = bright(red("Failed.")) + """
@@ -345,7 +368,7 @@ ERROR: subprocess.Popen(%r) failed to execute:
     %s
 
 Have you run `npm ci` from the bokehjs subdirectory?
-For more information, see the Dev Guide:
+For more information, see the Contributor Guide:
 
     https://docs.bokeh.org/en/latest/docs/dev_guide.html
 """
