@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -11,6 +11,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations
+
 import logging # isort:skip
 log = logging.getLogger(__name__)
 
@@ -21,13 +23,20 @@ log = logging.getLogger(__name__)
 # Bokeh imports
 from ..core.enums import MapType
 from ..core.has_props import abstract
-from ..core.properties import JSON, Bool, Enum, Float, Instance, Int, Override, String
-from ..core.validation import error, warning
-from ..core.validation.errors import (
-    INCOMPATIBLE_MAP_RANGE_TYPE,
-    MISSING_GOOGLE_API_KEY,
-    REQUIRED_RANGE,
+from ..core.properties import (
+    JSON,
+    Base64String,
+    Bool,
+    Enum,
+    Float,
+    Instance,
+    Int,
+    NonNullable,
+    Override,
+    String,
 )
+from ..core.validation import error, warning
+from ..core.validation.errors import INCOMPATIBLE_MAP_RANGE_TYPE, MISSING_GOOGLE_API_KEY, REQUIRED_RANGE
 from ..core.validation.warnings import MISSING_RENDERERS
 from ..model import Model
 from ..models.ranges import Range1d
@@ -54,11 +63,11 @@ class MapOptions(Model):
 
     '''
 
-    lat = Float(help="""
+    lat = NonNullable(Float, help="""
     The latitude where the map should be centered.
     """)
 
-    lng = Float(help="""
+    lng = NonNullable(Float, help="""
     The longitude where the map should be centered.
     """)
 
@@ -72,7 +81,7 @@ class MapPlot(Plot):
 
     '''
 
-    def __init__(self, *args, **kw):
+    def __init__(self, *args, **kw) -> None:
         from ..models.ranges import Range1d
         for r in ('x_range', 'y_range'):
             if r in kw and not isinstance(kw.get(r), Range1d):
@@ -103,7 +112,7 @@ class GMapOptions(MapOptions):
     Whether the Google map should display its distance scale control.
     """)
 
-    styles = JSON(help="""
+    styles = NonNullable(JSON, help="""
     A JSON array of `map styles`_ to use for the ``GMapPlot``. Many example styles can
     `be found here`_.
 
@@ -166,11 +175,20 @@ class GMapPlot(MapPlot):
 
     border_fill_color = Override(default="#ffffff")
 
-    api_key = String(help="""
+    api_key = NonNullable(Base64String, help="""
     Google Maps API requires an API key. See https://developers.google.com/maps/documentation/javascript/get-api-key
     for more information on how to obtain your own.
     """)
 
+    api_version = String(default="3.43", help="""
+    The version of Google Maps API to use. See https://developers.google.com/maps/documentation/javascript/versions
+    for more information.
+
+    .. note::
+        Changing this value may result in broken map rendering.
+
+    """)
+
     x_range = Override(default=lambda: Range1d())
 
     y_range = Override(default=lambda: Range1d())
