@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations
+
 import logging # isort:skip
 log = logging.getLogger(__name__)
 
@@ -21,13 +23,13 @@ import sys
 # Bokeh imports
 from ..core.properties import field
 from ..models import (
+    Circle,
     ColumnarDataSource,
     ColumnDataSource,
     GlyphRenderer,
     MultiLine,
     Scatter,
 )
-from ..models.markers import marker_types
 from ._renderer import make_glyph, pop_visuals
 
 #-----------------------------------------------------------------------------
@@ -74,18 +76,17 @@ def get_graph_kwargs(node_source, edge_source, **kwargs):
             raise ValueError(msg).with_traceback(sys.exc_info()[2])
 
     marker = kwargs.pop('node_marker', None)
+    marker_type = Scatter
     if isinstance(marker, dict) and 'field' in marker or marker in node_source.data:
-        marker_type = Scatter
         kwargs['node_marker'] = field(marker)
     else:
         if isinstance(marker, dict) and 'value' in marker:
             marker = marker['value']
-        elif marker is None:
-            marker = 'circle'
-        marker_type = marker_types.get(marker)
-    if marker_type is None:
-        msg = "Could not determine marker type for node_marker={marker}".format(marker=repr(marker))
-        raise ValueError(msg)
+
+        if marker is None or marker == "circle":
+            marker_type = Circle
+        else:
+            kwargs["node_marker"] = marker
 
     ## node stuff
     node_visuals = pop_visuals(marker_type, kwargs, prefix="node_")
@@ -100,10 +101,7 @@ def get_graph_kwargs(node_source, edge_source, **kwargs):
     else:
         hnode_visuals = None
 
-    if any(x.startswith('node_muted_') for x in kwargs):
-        mnode_visuals = pop_visuals(marker_type, kwargs, prefix="node_muted_", defaults=node_visuals)
-    else:
-        mnode_visuals = None
+    mnode_visuals = pop_visuals(marker_type, kwargs, prefix="node_muted_", defaults=node_visuals, override_defaults={'alpha':0.2})
 
     nsnode_visuals = pop_visuals(marker_type, kwargs, prefix="node_nonselection_", defaults=node_visuals)
 
@@ -120,10 +118,7 @@ def get_graph_kwargs(node_source, edge_source, **kwargs):
     else:
         hedge_visuals = None
 
-    if any(x.startswith('edge_muted_') for x in kwargs):
-        medge_visuals = pop_visuals(MultiLine, kwargs, prefix="edge_muted_", defaults=edge_visuals)
-    else:
-        medge_visuals = None
+    medge_visuals = pop_visuals(MultiLine, kwargs, prefix="edge_muted_", defaults=edge_visuals, override_defaults={'alpha':0.2})
 
     nsedge_visuals = pop_visuals(MultiLine, kwargs, prefix="edge_nonselection_", defaults=edge_visuals)
 
@@ -136,12 +131,14 @@ def get_graph_kwargs(node_source, edge_source, **kwargs):
     hnode_glyph = make_glyph(marker_type, node_kwargs, hnode_visuals)
     mnode_glyph = make_glyph(marker_type, node_kwargs, mnode_visuals)
 
-    node_renderer = GlyphRenderer(glyph=node_glyph,
-                                  nonselection_glyph=nsnode_glyph,
-                                  selection_glyph=snode_glyph,
-                                  hover_glyph=hnode_glyph,
-                                  muted_glyph=mnode_glyph,
-                                  data_source=node_source)
+    node_renderer = GlyphRenderer(
+        data_source=node_source,
+        glyph=node_glyph,
+        selection_glyph=snode_glyph or "auto",
+        nonselection_glyph=nsnode_glyph or "auto",
+        hover_glyph=hnode_glyph,
+        muted_glyph=mnode_glyph or "auto",
+    )
 
     ## edge stuff
     edge_kwargs = {k.lstrip('edge_'): v for k, v in kwargs.copy().items() if k.lstrip('edge_') in MultiLine.properties()}
@@ -152,12 +149,14 @@ def get_graph_kwargs(node_source, edge_source, **kwargs):
     hedge_glyph = make_glyph(MultiLine, edge_kwargs, hedge_visuals)
     medge_glyph = make_glyph(MultiLine, edge_kwargs, medge_visuals)
 
-    edge_renderer = GlyphRenderer(glyph=edge_glyph,
-                                  nonselection_glyph=nsedge_glyph,
-                                  selection_glyph=sedge_glyph,
-                                  hover_glyph=hedge_glyph,
-                                  muted_glyph=medge_glyph,
-                                  data_source=edge_source)
+    edge_renderer = GlyphRenderer(
+        data_source=edge_source,
+        glyph=edge_glyph,
+        selection_glyph=sedge_glyph or "auto",
+        nonselection_glyph=nsedge_glyph or "auto",
+        hover_glyph=hedge_glyph,
+        muted_glyph=medge_glyph or "auto",
+    )
 
     renderer_kwargs = {attr: kwargs.pop(attr) for attr in RENDERER_ARGS if attr in kwargs}
 
