@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -16,6 +18,7 @@ import pytest ; pytest
 
 # Bokeh imports
 from bokeh import __version__
+from bokeh._testing.util.types import Capture
 
 # Module under test
 from bokeh.command.bootstrap import main # isort:skip
@@ -28,7 +31,7 @@ from bokeh.command.bootstrap import main # isort:skip
 # Private API
 #-----------------------------------------------------------------------------
 
-def _assert_version_output(capsys):
+def _assert_version_output(capsys: Capture):
     out, err = capsys.readouterr()
     err_expected = ""
     out_expected = ("%s\n" % __version__)
@@ -43,24 +46,24 @@ def _assert_version_output(capsys):
 # Dev API
 #-----------------------------------------------------------------------------
 
-def test_no_subcommand(capsys) -> None:
+def test_no_subcommand(capsys: Capture) -> None:
     with pytest.raises(SystemExit):
         main(["bokeh"])
     out, err = capsys.readouterr()
     assert err == "ERROR: Must specify subcommand, one of: build, info, init, json, sampledata, secret, serve or static\n"
     assert out == ""
 
-def test_version(capsys) -> None:
+def test_version(capsys: Capture) -> None:
     with pytest.raises(SystemExit):
         main(["bokeh", "--version"])
     _assert_version_output(capsys)
 
-def test_version_short(capsys) -> None:
+def test_version_short(capsys: Capture) -> None:
     with pytest.raises(SystemExit):
         main(["bokeh", "-v"])
     _assert_version_output(capsys)
 
-def test_error(capsys) -> None:
+def test_error(capsys: Capture) -> None:
     from bokeh.command.subcommands.info import Info
     old_invoke = Info.invoke
     def err(x, y): raise RuntimeError("foo")
