@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -34,20 +36,26 @@ import bokeh.core.property.dataspec as bcpd # isort:skip
 #-----------------------------------------------------------------------------
 
 ALL = (
+    'AlphaSpec',
     'AngleSpec',
     'ColorSpec',
+    'DashPatternSpec',
     'DataSpec',
-    'DataDistanceSpec',
     'DistanceSpec',
     'expr',
     'field',
     'FontSizeSpec',
+    'FontStyleSpec',
     'HatchPatternSpec',
+    'IntSpec',
+    'LineCapSpec',
+    'LineJoinSpec',
     'MarkerSpec',
     'NumberSpec',
-    'ScreenDistanceSpec',
+    'SizeSpec',
     'StringSpec',
-    'UnitsSpec',
+    'TextAlignSpec',
+    'TextBaselineSpec',
     'value',
 )
 
@@ -56,7 +64,7 @@ ALL = (
 #-----------------------------------------------------------------------------
 
 def test_strict_dataspec_key_values() -> None:
-    for typ in (bcpd.NumberSpec, bcpd.StringSpec, bcpd.FontSizeSpec, bcpd.ColorSpec, bcpd.DataDistanceSpec, bcpd.ScreenDistanceSpec):
+    for typ in (bcpd.NumberSpec, bcpd.StringSpec, bcpd.FontSizeSpec, bcpd.ColorSpec, bcpd.SizeSpec):
         class Foo(HasProps):
             x = typ("x")
         f = Foo()
@@ -72,32 +80,8 @@ def test_dataspec_dict_to_serializable() -> None:
         assert props['x']['field'] == 'foo'
         assert props['x'] is not foo.x
 
-class Test_AngleSpec(object):
-
-    def test_default_none(self) -> None:
-        class Foo(HasProps):
-            x = bcpd.AngleSpec(None)
-
-        a = Foo()
-
-        assert a.x is None
-        assert a.x_units == 'rad'
-        a.x = 14
-        assert a.x == 14
-        assert a.x_units == 'rad'
-
-    def test_autocreate_no_parens(self) -> None:
-        class Foo(HasProps):
-            x = bcpd.AngleSpec
-
-        a = Foo()
-
-        assert a.x is None
-        assert a.x_units == 'rad'
-        a.x = 14
-        assert a.x == 14
-        assert a.x_units == 'rad'
 
+class Test_AngleSpec:
     def test_default_value(self) -> None:
         class Foo(HasProps):
             x = bcpd.AngleSpec(default=14)
@@ -152,8 +136,8 @@ class Test_AngleSpec(object):
 
         assert new_value_copy == new_value
 
-class Test_ColorSpec(object):
 
+class Test_ColorSpec:
     def test_field(self) -> None:
         class Foo(HasProps):
             col = bcpd.ColorSpec("colorfield")
@@ -284,42 +268,26 @@ class Test_ColorSpec(object):
         assert f.col == "field2"
         assert desc.serializable_value(f) == {"field": "field2"}
 
-class Test_DataDistanceSpec(object):
-    def test_basic(self) -> None:
-        assert issubclass(bcpd.DataDistanceSpec, bcpd.UnitsSpec)
-        class Foo(HasProps):
-            x = bcpd.DataDistanceSpec("x")
-        foo = Foo(x=dict(field='foo'))
-        props = foo.properties_with_values(include_defaults=False)
-        assert props['x']['units'] == 'data'
-        assert props['x']['field'] == 'foo'
-        assert props['x'] is not foo.x
+    def test_isconst(self) -> None:
+        assert bcpd.ColorSpec.isconst("red")
+        assert bcpd.ColorSpec.isconst("#ff1234")
 
-class Test_DistanceSpec(object):
-    def test_default_none(self) -> None:
-        class Foo(HasProps):
-            x = bcpd.DistanceSpec(None)
+        assert not bcpd.ColorSpec.isconst(None)
+        assert not bcpd.ColorSpec.isconst(10)
+        assert not bcpd.ColorSpec.isconst((1, 2, 3, 0.5))
 
-        a = Foo()
+    def test_is_color_tuple_shape(self) -> None:
+        assert bcpd.ColorSpec.is_color_tuple_shape((1, 2, 3, 0.5))
+        assert bcpd.ColorSpec.is_color_tuple_shape((1.0, 2, 3, 0.5))
+        assert bcpd.ColorSpec.is_color_tuple_shape((1, 2.0, 3, 0.5))
+        assert bcpd.ColorSpec.is_color_tuple_shape((1, 2, 3.0, 0.5))
 
-        assert a.x is None
-        assert a.x_units == 'data'
-        a.x = 14
-        assert a.x == 14
-        assert a.x_units == 'data'
-
-    def test_autocreate_no_parens(self) -> None:
-        class Foo(HasProps):
-            x = bcpd.DistanceSpec
-
-        a = Foo()
-
-        assert a.x is None
-        assert a.x_units == 'data'
-        a.x = 14
-        assert a.x == 14
-        assert a.x_units == 'data'
+        assert not bcpd.ColorSpec.is_color_tuple_shape("red")
+        assert not bcpd.ColorSpec.is_color_tuple_shape("#ff1234")
+        assert not bcpd.ColorSpec.is_color_tuple_shape(None)
+        assert not bcpd.ColorSpec.is_color_tuple_shape(10)
 
+class Test_DistanceSpec:
     def test_default_value(self) -> None:
         class Foo(HasProps):
             x = bcpd.DistanceSpec(default=14)
@@ -334,15 +302,15 @@ def test_field_function() -> None:
     assert bcpd.field("foo", "junk") == dict(field="foo", transform="junk")
     assert bcpd.field("foo", transform="junk") == dict(field="foo", transform="junk")
 
-class Test_FontSizeSpec(object):
+class Test_FontSizeSpec:
     def test_font_size_from_string(self) -> None:
         class Foo(HasProps):
-            x = bcpd.FontSizeSpec(default=None)
+            x = bcpd.FontSizeSpec(default="0px")
 
         css_units = "%|em|ex|ch|ic|rem|vw|vh|vi|vb|vmin|vmax|cm|mm|q|in|pc|pt|px"
 
         a = Foo()
-        assert a.x is None
+        assert a.x == "0px"
 
         for unit in css_units.split("|"):
 
@@ -389,7 +357,7 @@ class Test_FontSizeSpec(object):
 
     def test_bad_font_size_values(self) -> None:
         class Foo(HasProps):
-            x = bcpd.FontSizeSpec(default=None)
+            x = bcpd.FontSizeSpec(default="0px")
 
         a = Foo()
 
@@ -404,7 +372,7 @@ class Test_FontSizeSpec(object):
 
     def test_fields(self) -> None:
         class Foo(HasProps):
-            x = bcpd.FontSizeSpec(default=None)
+            x = bcpd.FontSizeSpec(default="0px")
 
         a = Foo()
 
@@ -420,8 +388,8 @@ class Test_FontSizeSpec(object):
         a.x = dict(field="foo")
         assert a.x == dict(field="foo")
 
-class Test_NumberSpec(object):
 
+class Test_NumberSpec:
     def test_field(self) -> None:
         class Foo(HasProps):
             x = bcpd.NumberSpec("xfield")
@@ -445,8 +413,6 @@ class Test_NumberSpec(object):
         assert Foo.__dict__["x"].serializable_value(f) == {"value": 15}
         f.x = dict(value=32)
         assert Foo.__dict__["x"].serializable_value(f) == {"value": 32}
-        f.x = None
-        assert Foo.__dict__["x"].serializable_value(f) is None
 
     def tests_accepts_timedelta(self):
         class Foo(HasProps):
@@ -543,23 +509,13 @@ class Test_NumberSpec(object):
         assert Foo.__dict__["x"].serializable_value(a) == {"value": 13}
         assert Foo.__dict__["x"].serializable_value(b) == {"field": "x3"}
 
-    def test_autocreate_no_parens(self) -> None:
-        class Foo(HasProps):
-            x = bcpd.NumberSpec
-
-        a = Foo()
-
-        assert a.x is None
-        a.x = 14
-        assert a.x == 14
-
     def test_set_from_json_keeps_mode(self) -> None:
         class Foo(HasProps):
-            x = bcpd.NumberSpec(default=None)
+            x = bcpd.NumberSpec(default=-1)
 
         a = Foo()
 
-        assert a.x is None
+        assert a.x == -1
 
         # set as a value
         a.x = 14
@@ -581,18 +537,8 @@ class Test_NumberSpec(object):
         a.x = dict(field="baz")
         assert a.x == dict(field="baz")
 
-class Test_UnitSpec(object):
-
-    def test_basic(self) -> None:
-        assert issubclass(bcpd.ScreenDistanceSpec, bcpd.UnitsSpec)
-        class Foo(HasProps):
-            x = bcpd.ScreenDistanceSpec("x")
-        foo = Foo(x=dict(field='foo'))
-        props = foo.properties_with_values(include_defaults=False)
-        assert props['x']['units'] == 'screen'
-        assert props['x']['field'] == 'foo'
-        assert props['x'] is not foo.x
 
+class Test_UnitSpec:
     def test_strict_key_values(self) -> None:
         class FooUnits(HasProps):
             x = bcpd.DistanceSpec("x")
