@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -18,17 +20,19 @@ import pytest ; pytest
 import base64
 import datetime
 from io import BytesIO
+from pathlib import Path
 
 # External imports
 import numpy as np
 import PIL.Image
 
 # Bokeh imports
-from _util_property import _TestHasProps, _TestModel
 from bokeh._testing.util.api import verify_all
 from bokeh.core.enums import MarkerType
 from bokeh.core.has_props import HasProps
 
+from _util_property import _TestHasProps, _TestModel
+
 # Module under test
 import bokeh.core.property.visual as bcpv # isort:skip
 
@@ -107,8 +111,6 @@ class TestDashPattern:
     def test_valid(self) -> None:
         prop = bcpv.DashPattern()
 
-        assert prop.is_valid(None)
-
         assert prop.is_valid("")
         assert prop.is_valid(())
         assert prop.is_valid([])
@@ -126,6 +128,7 @@ class TestDashPattern:
     def test_invalid(self) -> None:
         prop = bcpv.DashPattern()
 
+        assert not prop.is_valid(None)
         assert not prop.is_valid(False)
         assert not prop.is_valid(True)
         assert not prop.is_valid(0)
@@ -158,8 +161,6 @@ class Test_FontSize:
     def test_valid(self) -> None:
         prop = bcpv.FontSize()
 
-        assert prop.is_valid(None)
-
         for unit in css_units.split("|"):
             v = '10%s' % unit
             assert prop.is_valid(v)
@@ -191,6 +192,7 @@ class Test_FontSize:
             v = '_10.2%s' % unit
             assert not prop.is_valid(v)
 
+        assert not prop.is_valid(None)
         assert not prop.is_valid(False)
         assert not prop.is_valid(True)
         assert not prop.is_valid(0)
@@ -220,11 +222,19 @@ class Test_Image:
 
     def test_validate_None(self) -> None:
         prop = bcpv.Image()
-        assert prop.is_valid(None)
+        assert not prop.is_valid(None)
 
-    def test_validate_string(self) -> None:
+    def test_validate_data_url(self) -> None:
         prop = bcpv.Image()
-        assert prop.is_valid("string")
+        assert prop.is_valid("data:image/png;base64,")
+
+    def test_validate_Path(self) -> None:
+        prop = bcpv.Image()
+        assert prop.is_valid(Path("some/path"))
+
+    def test_validate_raw_path(self) -> None:
+        prop = bcpv.Image()
+        assert prop.is_valid("some/path")
 
     @pytest.mark.parametrize('typ', ('png', 'gif', 'tiff'))
     def test_validate_PIL(self, typ) -> None:
@@ -261,9 +271,10 @@ class Test_Image:
         data = np.zeros((50, 50), dtype=np.uint8)
         assert not prop.is_valid(data)
 
-    def test_transform_None(self) -> None:
+    def test_transform_data_url(self) -> None:
         prop = bcpv.Image()
-        assert prop.transform(None) is None
+        image = "data:image/png;base64,"
+        assert prop.transform(image) == image
 
     def test_transform_numpy(self) -> None:
         data = np.zeros((50, 50, 3), dtype=np.uint8)
@@ -306,7 +317,6 @@ class Test_MinMaxBounds:
         prop = bcpv.MinMaxBounds(accept_datetime=False)
 
         assert prop.is_valid('auto')
-        assert prop.is_valid(None)
         assert prop.is_valid((12, 13))
         assert prop.is_valid((-32, -13))
         assert prop.is_valid((12.1, 13.1))
@@ -316,6 +326,7 @@ class Test_MinMaxBounds:
     def test_invalid_no_datetime(self) -> None:
         prop = bcpv.MinMaxBounds(accept_datetime=False)
 
+        assert not prop.is_valid(None)
         assert not prop.is_valid('string')
         assert not prop.is_valid(12)
         assert not prop.is_valid(('a', 'b'))
@@ -343,14 +354,13 @@ class Test_MarkerType:
     def test_valid(self) -> None:
         prop = bcpv.MarkerType()
 
-        assert prop.is_valid(None)
-
         for typ in MarkerType:
             assert prop.is_valid(typ)
 
     def test_invalid(self) -> None:
         prop = bcpv.MarkerType()
 
+        assert not prop.is_valid(None)
         assert not prop.is_valid(False)
         assert not prop.is_valid(True)
         assert not prop.is_valid(0)
