@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -30,6 +32,7 @@ ALL  = (
     'Align',
     'Anchor',
     'AngleUnits',
+    'AutosizeMode',
     'ButtonType',
     'CalendarPosition',
     'DashPattern',
@@ -61,6 +64,7 @@ ALL  = (
     'OutputBackend',
     'PaddingUnits',
     'Palette',
+    'Place',
     'RenderLevel',
     'RenderMode',
     'ResetPolicy',
@@ -95,7 +99,7 @@ def test_Enumeration_default() -> None:
     e = bce.Enumeration()
     assert e.__slots__ == ()
 
-class Test_enumeration(object):
+class Test_enumeration:
     def test_basic(self) -> None:
         e = bce.enumeration("foo", "bar", "baz")
         assert isinstance(e, bce.Enumeration)
@@ -132,20 +136,21 @@ class Test_enumeration(object):
         e = bce.enumeration("foo", "bar", "baz")
         assert len(e) == 3
 
-class Test_bce(object):
 
+class Test_bce:
     def test_Anchor(self) -> None:
         assert tuple(bce.Anchor) == (
             "top_left",    "top_center",    "top_right",
-            "center_left", "center",        "center_right",
-            "bottom_left", "bottom_center", "bottom_right"
+            "center_left", "center_center", "center_right",
+            "bottom_left", "bottom_center", "bottom_right",
+            "top", "left", "center", "right", "bottom",
         )
 
     def test_AngleUnits(self) -> None:
-        assert tuple(bce.AngleUnits) == ('deg', 'rad')
+        assert tuple(bce.AngleUnits) == ("deg", "rad", "grad", "turn")
 
     def test_ButtonType(self) -> None:
-        assert tuple(bce.ButtonType) == ("default", "primary", "success", "warning", "danger")
+        assert tuple(bce.ButtonType) == ("default", "primary", "success", "warning", "danger", "light")
 
     def test_CalendarPosition(self) -> None:
         assert tuple(bce.CalendarPosition) == ("auto", "above", "below")
@@ -201,8 +206,9 @@ class Test_bce(object):
     def test_LegendLocation(self) -> None:
         assert tuple(bce.LegendLocation) == (
             "top_left",    "top_center",    "top_right",
-            "center_left", "center",        "center_right",
-            "bottom_left", "bottom_center", "bottom_right"
+            "center_left", "center_center", "center_right",
+            "bottom_left", "bottom_center", "bottom_right",
+            "top", "left", "center", "right", "bottom",
         )
 
     def test_LineCap(self) -> None:
@@ -223,11 +229,11 @@ class Test_bce(object):
     def test_MarkerType(self) -> None:
         assert tuple(bce.MarkerType) == ("asterisk", "circle", "circle_cross", "circle_dot", "circle_x", "circle_y", "cross",
                                          "dash", "diamond", "diamond_cross", "diamond_dot", "dot", "hex", "hex_dot", "inverted_triangle",
-                                         "plus", "square", "square_cross", "square_dot", "square_pin", "square_x", "triangle",
-                                         "triangle_dot", "triangle_pin", "x", "y")
+                                         "plus", "square", "square_cross", "square_dot", "square_pin", "square_x", "star", "star_dot",
+                                         "triangle", "triangle_dot", "triangle_pin", "x", "y")
 
     def test_NamedColor(self) -> None:
-        assert len(tuple(bce.NamedColor)) == 147
+        assert len(tuple(bce.NamedColor)) == 148
         assert tuple(bce.NamedColor) == tuple(named.__all__)
 
     def test_NumeralLanguage(self) -> None:
@@ -304,10 +310,11 @@ class Test_bce(object):
 
 # any changes to contents of bce.py easily trackable here
 def test_enums_contents() -> None:
-    assert [x for x in dir(bce) if x[0].isupper()] == [
+    assert [ name for name in dir(bce) if isinstance(getattr(bce, name), bce.Enumeration) ] == [
         'Align',
         'Anchor',
         'AngleUnits',
+        'AutosizeMode',
         'ButtonType',
         'CalendarPosition',
         'DashPattern',
@@ -316,7 +323,6 @@ def test_enums_contents() -> None:
         'Dimension',
         'Dimensions',
         'Direction',
-        'Enumeration',
         'FontStyle',
         'HatchPattern',
         'HatchPatternAbbreviation',
@@ -338,6 +344,7 @@ def test_enums_contents() -> None:
         'OutputBackend',
         'PaddingUnits',
         'Palette',
+        'Place',
         'RenderLevel',
         'RenderMode',
         'ResetPolicy',
