@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -34,6 +36,7 @@ ALL = (
     'push_notebook',
     'output_file',
     'output_notebook',
+    'reset_output',
     'save',
     'show',
 )
