@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -21,25 +23,12 @@ from datetime import datetime
 import mock
 
 # Bokeh imports
-from _util_models import (
-    ANGLE,
-    FILL,
-    LINE,
-    TEXT,
-    check_fill_properties,
-    check_line_properties,
-    check_properties_existence,
-    check_text_properties,
-    prefix,
-)
 from bokeh.core.properties import field, value
-from bokeh.core.validation import check_integrity
+from bokeh.core.validation import check_integrity, process_validation_issues
 from bokeh.models import (
     Arrow,
     ArrowHead,
     Band,
-    BasicTicker,
-    BasicTickFormatter,
     BoxAnnotation,
     ColorBar,
     ColumnDataSource,
@@ -48,16 +37,40 @@ from bokeh.models import (
     LabelSet,
     Legend,
     LegendItem,
+    LinearColorMapper,
+    PolyAnnotation,
     Slope,
     Span,
     Title,
     Whisker,
 )
 
+from _util_models import (
+    ANGLE,
+    FILL,
+    HATCH,
+    LINE,
+    TEXT,
+    check_fill_properties,
+    check_hatch_properties,
+    check_line_properties,
+    check_properties_existence,
+    check_text_properties,
+    prefix,
+)
+
 #-----------------------------------------------------------------------------
 # Setup
 #-----------------------------------------------------------------------------
 
+ANNOTATION = [
+    "visible",
+    "level",
+    "coordinates",
+    "x_range_name",
+    "y_range_name",
+    "group",
+]
 
 #-----------------------------------------------------------------------------
 # General API
@@ -81,8 +94,7 @@ def test_Legend() -> None:
     check_line_properties(legend, "border_", "#e5e5e5", 1.0, 0.5)
     check_text_properties(legend, "label_", "13px", "middle", scalar=True)
     check_fill_properties(legend, "background_", "#ffffff", 0.95)
-    check_properties_existence(legend, [
-        "visible",
+    check_properties_existence(legend, ANNOTATION + [
         "location",
         "orientation",
         "title",
@@ -96,27 +108,36 @@ def test_Legend() -> None:
         "padding",
         "spacing",
         "items",
-        "level",
-        "click_policy"],
+        "click_policy",
+    ],
         prefix('label_', TEXT),
         prefix('title_', TEXT),
         prefix('border_', LINE),
         prefix('background_', FILL),
-        prefix('inactive_', FILL))
+        prefix('inactive_', FILL),
+    )
 
+def test_LegendItem() -> None:
+    item = LegendItem()
+    assert item.index== None
+    assert item.label == None
+    assert item.name is None
+    assert item.renderers == []
+    assert item.visible == True
 
 def test_ColorBar() -> None:
-    color_bar = ColorBar()
+    color_mapper = LinearColorMapper()
+    color_bar = ColorBar(color_mapper=color_mapper)
     assert color_bar.location == 'top_right'
-    assert color_bar.orientation == 'vertical'
+    assert color_bar.orientation == 'auto'
     assert color_bar.height == 'auto'
     assert color_bar.width == 'auto'
     assert color_bar.scale_alpha == 1.0
     assert color_bar.title is None
     assert color_bar.title_standoff == 2
-    assert isinstance(color_bar.ticker, BasicTicker)
-    assert isinstance(color_bar.formatter, BasicTickFormatter)
-    assert color_bar.color_mapper is None
+    assert color_bar.ticker == "auto"
+    assert color_bar.formatter == "auto"
+    assert color_bar.color_mapper == color_mapper
     assert color_bar.margin == 30
     assert color_bar.padding == 10
     assert color_bar.label_standoff == 5
@@ -125,15 +146,13 @@ def test_ColorBar() -> None:
     assert color_bar.minor_tick_in == 0
     assert color_bar.minor_tick_out == 0
     check_text_properties(color_bar, "title_", "13px", "bottom", "italic", scalar=True)
-    check_text_properties(color_bar, "major_label_", "11px", "middle", "normal", "center", scalar=True)
+    check_text_properties(color_bar, "major_label_", "11px", "bottom", "normal", "left", scalar=True)
     check_line_properties(color_bar, "major_tick_", "#ffffff")
     check_line_properties(color_bar, "minor_tick_", None)
     check_line_properties(color_bar, "bar_", None)
     check_line_properties(color_bar, "border_", None)
     check_fill_properties(color_bar, "background_", "#ffffff", 0.95)
-    check_properties_existence(color_bar, [
-        "level",
-        "visible",
+    check_properties_existence(color_bar, ANNOTATION + [
         "location",
         "orientation",
         "height",
@@ -151,34 +170,34 @@ def test_ColorBar() -> None:
         "major_tick_out",
         "minor_tick_in",
         "minor_tick_out",
-        "major_label_overrides"],
+        "major_label_overrides",
+        "major_label_policy",
+    ],
         prefix('title_', TEXT),
         prefix('major_label_', TEXT),
         prefix('major_tick_', LINE),
         prefix('minor_tick_', LINE),
         prefix('bar_', LINE),
         prefix('border_', LINE),
-        prefix('background_', FILL)
+        prefix('background_', FILL),
     )
 
 
 def test_Arrow() -> None:
     arrow = Arrow()
-    assert arrow.x_start is None
-    assert arrow.y_start is None
+    assert arrow.x_start == field("x_start")
+    assert arrow.y_start == field("y_start")
     assert arrow.start_units == 'data'
     assert arrow.start is None
-    assert arrow.x_end is None
-    assert arrow.y_end is None
+    assert arrow.x_end == field("x_end")
+    assert arrow.y_end == field("y_end")
     assert arrow.end_units == 'data'
     assert isinstance(arrow.end, ArrowHead)
-    assert arrow.source is None
+    assert isinstance(arrow.source, ColumnDataSource)
     assert arrow.x_range_name == "default"
     assert arrow.y_range_name == "default"
     check_line_properties(arrow)
-    check_properties_existence(arrow, [
-        "level",
-        "visible",
+    check_properties_existence(arrow, ANNOTATION + [
         "x_start",
         "y_start",
         "start_units",
@@ -188,29 +207,27 @@ def test_Arrow() -> None:
         "end_units",
         "end",
         "source",
-        "x_range_name",
-        "y_range_name"],
-        LINE)
+    ], LINE)
 
 
 def test_BoxAnnotation() -> None:
     box = BoxAnnotation()
     assert box.left is None
-    assert box.left_units == 'data'
+    assert box.left_units == "data"
     assert box.right is None
-    assert box.right_units == 'data'
+    assert box.right_units == "data"
     assert box.bottom is None
-    assert box.bottom_units == 'data'
+    assert box.bottom_units == "data"
     assert box.top is None
-    assert box.top_units == 'data'
-    assert box.x_range_name == 'default'
-    assert box.y_range_name == 'default'
-    assert box.level == 'annotation'
-    check_line_properties(box, "", '#cccccc', 1, 0.3)
+    assert box.top_units == "data"
+    assert box.x_range_name == "default"
+    assert box.y_range_name == "default"
+    assert box.level == "annotation"
+    check_line_properties(box, "", "#cccccc", 1, 0.3)
     check_fill_properties(box, "", "#fff9ba", 0.4)
-    check_properties_existence(box, [
+    check_hatch_properties(box)
+    check_properties_existence(box, ANNOTATION + [
         "render_mode",
-        "visible",
         "left",
         "left_units",
         "right",
@@ -219,29 +236,24 @@ def test_BoxAnnotation() -> None:
         "bottom_units",
         "top",
         "top_units",
-        "x_range_name",
-        "y_range_name",
-        "level",
-    ], LINE, FILL)
+    ], LINE, FILL, HATCH)
 
 
 def test_Band() -> None:
     band = Band()
     assert band.level == 'annotation'
-    assert band.lower is None
+    assert band.lower == field("lower")
     assert band.lower_units == 'data'
-    assert band.upper is None
+    assert band.upper == field("upper")
     assert band.upper_units == 'data'
-    assert band.base is None
+    assert band.base == field("base")
     assert band.dimension == 'height'
     assert isinstance(band.source, ColumnDataSource)
     assert band.x_range_name == 'default'
     assert band.y_range_name == 'default'
     check_line_properties(band, "", "#cccccc", 1.0, 0.3)
     check_fill_properties(band, "", "#fff9ba", 0.4)
-    check_properties_existence(band, [
-        "visible",
-        "level",
+    check_properties_existence(band, ANNOTATION + [
         "lower",
         "lower_units",
         "upper",
@@ -250,19 +262,17 @@ def test_Band() -> None:
         "base_units",
         "dimension",
         "source",
-        "x_range_name",
-        "y_range_name",
     ], LINE, FILL)
 
 
 def test_Label() -> None:
-    label = Label()
+    label = Label(x=11, y=12)
     assert label.level == 'annotation'
-    assert label.x is None
-    assert label.y is None
+    assert label.x == 11
+    assert label.y == 12
     assert label.x_units == 'data'
     assert label.y_units == 'data'
-    assert label.text is None
+    assert label.text == ""
     assert label.angle == 0
     assert label.angle_units == 'rad'
     assert label.x_offset == 0
@@ -273,9 +283,7 @@ def test_Label() -> None:
     check_text_properties(label, scalar=True)
     check_fill_properties(label, "background_", None, 1.0)
     check_line_properties(label, "border_", None, 1.0, 1.0)
-    check_properties_existence(label, [
-        "level",
-        "visible",
+    check_properties_existence(label, ANNOTATION + [
         "x",
         "y",
         "x_units",
@@ -286,11 +294,11 @@ def test_Label() -> None:
         "x_offset",
         "y_offset",
         "render_mode",
-        "x_range_name",
-        "y_range_name"],
+    ],
         TEXT,
         prefix('border_', LINE),
-        prefix('background_', FILL))
+        prefix('background_', FILL),
+    )
 
 def test_Label_accepts_datetime_xy() -> None:
     obj = Label(x = datetime(2018,8,7,0,0),
@@ -301,11 +309,11 @@ def test_Label_accepts_datetime_xy() -> None:
 def test_LabelSet() -> None:
     label_set = LabelSet()
     assert label_set.level == 'annotation'
-    assert label_set.x is None
-    assert label_set.y is None
+    assert label_set.x == field("x")
+    assert label_set.y == field("y")
     assert label_set.x_units == 'data'
     assert label_set.y_units == 'data'
-    assert label_set.text == 'text'
+    assert label_set.text == field("text")
     assert label_set.angle == 0
     assert label_set.angle_units == 'rad'
     assert label_set.x_offset == 0
@@ -318,9 +326,7 @@ def test_LabelSet() -> None:
     check_text_properties(label_set)
     check_fill_properties(label_set, "background_", None, 1.0)
     check_line_properties(label_set, "border_", None, 1.0, 1.0)
-    check_properties_existence(label_set, [
-        "visible",
-        "level",
+    check_properties_existence(label_set, ANNOTATION + [
         "x",
         "y",
         "x_units",
@@ -331,13 +337,32 @@ def test_LabelSet() -> None:
         "x_offset",
         "y_offset",
         "render_mode",
-        "x_range_name",
-        "y_range_name",
-        "source"],
+        "source",
+    ],
         TEXT,
         ANGLE,
         prefix('border_', LINE),
-        prefix('background_', FILL))
+        prefix('background_', FILL),
+    )
+
+def test_PolyAnnotation() -> None:
+    poly = PolyAnnotation()
+    assert poly.xs == []
+    assert poly.xs_units == "data"
+    assert poly.ys == []
+    assert poly.ys_units == "data"
+    assert poly.x_range_name == "default"
+    assert poly.y_range_name == "default"
+    assert poly.level == "annotation"
+    check_line_properties(poly, "", "#cccccc", 1, 0.3)
+    check_fill_properties(poly, "", "#fff9ba", 0.4)
+    check_hatch_properties(poly)
+    check_properties_existence(poly, ANNOTATION + [
+        "xs",
+        "xs_units",
+        "ys",
+        "ys_units",
+    ], LINE, FILL, HATCH)
 
 def test_Slope() -> None:
     slope = Slope()
@@ -347,13 +372,9 @@ def test_Slope() -> None:
     assert slope.y_range_name == 'default'
     assert slope.level == 'annotation'
     check_line_properties(slope, "", 'black', 1.0)
-    check_properties_existence(slope, [
-        "visible",
+    check_properties_existence(slope, ANNOTATION + [
         "gradient",
         "y_intercept",
-        "x_range_name",
-        "y_range_name",
-        "level",
     ], LINE)
 
 
@@ -367,14 +388,10 @@ def test_Span() -> None:
     assert line.level == 'annotation'
     assert line.render_mode == 'canvas'
     check_line_properties(line, "", 'black', 1.0)
-    check_properties_existence(line, [
-        "visible",
+    check_properties_existence(line, ANNOTATION + [
         "location",
         "location_units",
         "dimension",
-        "x_range_name",
-        "y_range_name",
-        "level",
         "render_mode"
     ], LINE)
 
@@ -385,7 +402,7 @@ def test_Span_accepts_datetime_location() -> None:
 def test_Title() -> None:
     title = Title()
     assert title.level == 'annotation'
-    assert title.text is None
+    assert title.text == ""
     assert title.vertical_align == 'bottom'
     assert title.align == 'left'
     assert title.offset == 0
@@ -397,46 +414,43 @@ def test_Title() -> None:
     assert title.text_line_height == 1.0
     check_fill_properties(title, "background_", None, 1.0)
     check_line_properties(title, "border_", None, 1.0, 1.0)
-    check_properties_existence(title, [
-        "visible",
-        "level",
+    check_properties_existence(title, ANNOTATION + [
         "text",
         "vertical_align",
         "align",
         "offset",
+        "standoff",
         "text_font",
         "text_font_size",
         "text_font_style",
         "text_color",
         "text_alpha",
         "text_line_height",
-        "render_mode"],
+        "render_mode",
+    ],
         prefix('border_', LINE),
-        prefix('background_', FILL))
+        prefix('background_', FILL),
+    )
 
 
 def test_Whisker() -> None:
     whisker = Whisker()
     assert whisker.level == 'underlay'
-    assert whisker.lower is None
+    assert whisker.lower == field("lower")
     assert whisker.lower_units == 'data'
     assert isinstance(whisker.lower_head, ArrowHead)
     assert whisker.lower_head.size == 10
-    assert whisker.lower_head.level == 'underlay'
-    assert whisker.upper is None
+    assert whisker.upper == field("upper")
     assert whisker.upper_units == 'data'
     assert isinstance(whisker.upper_head, ArrowHead)
     assert whisker.upper_head.size == 10
-    assert whisker.upper_head.level == 'underlay'
-    assert whisker.base is None
+    assert whisker.base == field("base")
     assert whisker.dimension == 'height'
     assert isinstance(whisker.source, ColumnDataSource)
     assert whisker.x_range_name == 'default'
     assert whisker.y_range_name == 'default'
     check_line_properties(whisker, "")
-    check_properties_existence(whisker, [
-        "visible",
-        "level",
+    check_properties_existence(whisker, ANNOTATION + [
         "lower",
         "lower_units",
         "lower_head",
@@ -447,9 +461,7 @@ def test_Whisker() -> None:
         "base_units",
         "dimension",
         "source",
-        "x_range_name",
-        "y_range_name"],
-        LINE)
+    ], LINE)
 
 def test_Whisker_and_Band_accept_negative_values() -> None:
     whisker = Whisker(base=-1., lower=-1.5, upper=-0.5)
@@ -463,11 +475,12 @@ def test_Whisker_and_Band_accept_negative_values() -> None:
 
 def test_can_add_multiple_glyph_renderers_to_legend_item() -> None:
     legend_item = LegendItem()
-    gr_1 = GlyphRenderer()
-    gr_2 = GlyphRenderer()
+    gr_1 = GlyphRenderer(data_source=ColumnDataSource())
+    gr_2 = GlyphRenderer(data_source=ColumnDataSource())
     legend_item.renderers = [gr_1, gr_2]
     with mock.patch('bokeh.core.validation.check.log') as mock_logger:
-        check_integrity([legend_item])
+        issues = check_integrity([legend_item])
+        process_validation_issues(issues)
         assert mock_logger.error.call_count == 0
 
 
@@ -478,7 +491,8 @@ def test_legend_item_with_field_label_and_different_data_sources_raises_a_valida
     legend_item.label = field('label')
     legend_item.renderers = [gr_1, gr_2]
     with mock.patch('bokeh.core.validation.check.log') as mock_logger:
-        check_integrity([legend_item])
+        issues = check_integrity([legend_item])
+        process_validation_issues(issues)
         assert mock_logger.error.call_count == 1
 
 
@@ -489,7 +503,8 @@ def test_legend_item_with_value_label_and_different_data_sources_does_not_raise_
     legend_item.label = value('label')
     legend_item.renderers = [gr_1, gr_2]
     with mock.patch('bokeh.core.validation.check.log') as mock_logger:
-        check_integrity([legend_item])
+        issues = check_integrity([legend_item])
+        process_validation_issues(issues)
         assert mock_logger.error.call_count == 0
 
 
@@ -499,7 +514,8 @@ def test_legend_item_with_field_label_raises_error_if_field_not_in_cds() -> None
     legend_item.label = field('label')
     legend_item.renderers = [gr_1]
     with mock.patch('bokeh.core.validation.check.log') as mock_logger:
-        check_integrity([legend_item])
+        issues = check_integrity([legend_item])
+        process_validation_issues(issues)
         assert mock_logger.error.call_count == 1
 
 #-----------------------------------------------------------------------------
