@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -16,12 +18,13 @@ import pytest ; pytest
 
 # External imports
 import mock
-from mock import patch
+from mock import MagicMock, patch
 
 # Bokeh imports
-from bokeh.core.validation import check_integrity
+from bokeh.core.validation import check_integrity, process_validation_issues
 from bokeh.models import (
     CategoricalScale,
+    CustomJS,
     DataRange1d,
     FactorRange,
     GlyphRenderer,
@@ -32,6 +35,7 @@ from bokeh.models import (
     PanTool,
     Plot,
     Range1d,
+    Title,
 )
 from bokeh.plotting import figure
 
@@ -78,26 +82,26 @@ class TestPlotSelect:
         self._plot.circle([1,2,3], [3,2,1], name='foo')
 
     @patch('bokeh.models.plots.find')
-    def test_string_arg(self, mock_find) -> None:
+    def test_string_arg(self, mock_find: MagicMock) -> None:
         self._plot.select('foo')
         assert mock_find.called
         assert mock_find.call_args[0][1] == dict(name='foo')
 
     @patch('bokeh.models.plots.find')
-    def test_type_arg(self, mock_find) -> None:
+    def test_type_arg(self, mock_find: MagicMock) -> None:
         self._plot.select(PanTool)
         assert mock_find.called
         assert mock_find.call_args[0][1] == dict(type=PanTool)
 
     @patch('bokeh.models.plots.find')
-    def test_kwargs(self, mock_find) -> None:
+    def test_kwargs(self, mock_find: MagicMock) -> None:
         kw = dict(name='foo', type=GlyphRenderer)
         self._plot.select(**kw)
         assert mock_find.called
         assert mock_find.call_args[0][1] == kw
 
     @patch('bokeh.models.plots.find')
-    def test_single_selector_kwarg(self, mock_find) -> None:
+    def test_single_selector_kwarg(self, mock_find: MagicMock) -> None:
         kw = dict(name='foo', type=GlyphRenderer)
         self._plot.select(selector=kw)
         assert mock_find.called
@@ -134,66 +138,62 @@ class TestPlotValidation:
         p = figure()
         p.renderers = []
         with mock.patch('bokeh.core.validation.check.log') as mock_logger:
-            check_integrity([p])
+            issues = check_integrity([p])
+            process_validation_issues(issues)
         assert mock_logger.warning.call_count == 1
         assert mock_logger.warning.call_args[0][0].startswith("W-1000 (MISSING_RENDERERS): Plot has no renderers")
 
     def test_missing_scale(self) -> None:
         p = figure()
-        p.x_scale = None
-        with mock.patch('bokeh.core.validation.check.log') as mock_logger:
-            check_integrity([p])
-        assert mock_logger.error.call_count == 1
-        assert mock_logger.error.call_args[0][0].startswith("E-1008 (REQUIRED_SCALE): A required Scale object is missing: x_scale")
 
-        p.y_scale = None
-        with mock.patch('bokeh.core.validation.check.log') as mock_logger:
-            check_integrity([p])
-        assert mock_logger.error.call_count == 1
-        assert mock_logger.error.call_args[0][0].startswith("E-1008 (REQUIRED_SCALE): A required Scale object is missing: x_scale, y_scale")
+        with pytest.raises(ValueError):
+            p.x_scale = None
+
+        with pytest.raises(ValueError):
+            p.y_scale = None
 
     def test_missing_range(self) -> None:
         p = figure()
-        p.x_range = None
-        with mock.patch('bokeh.core.validation.check.log') as mock_logger:
-            check_integrity([p])
-        assert mock_logger.error.call_count == 1
-        assert mock_logger.error.call_args[0][0].startswith("E-1004 (REQUIRED_RANGE): A required Range object is missing: x_range")
 
-        p.y_range = None
-        with mock.patch('bokeh.core.validation.check.log') as mock_logger:
-            check_integrity([p])
-        assert mock_logger.error.call_count == 1
-        assert mock_logger.error.call_args[0][0].startswith("E-1004 (REQUIRED_RANGE): A required Range object is missing: x_range, y_range")
+        with pytest.raises(ValueError):
+            p.x_range = None
+
+        with pytest.raises(ValueError):
+            p.y_range = None
 
     def test_bad_extra_range_name(self) -> None:
         p = figure()
         p.xaxis.x_range_name="junk"
         with mock.patch('bokeh.core.validation.check.log') as mock_logger:
-            check_integrity([p])
+            issues = check_integrity([p])
+            process_validation_issues(issues)
         assert mock_logger.error.call_count == 1
         assert mock_logger.error.call_args[0][0].startswith(
-            "E-1020 (BAD_EXTRA_RANGE_NAME): An extra range name is configued with a name that does not correspond to any range: x_range_name='junk' [LinearAxis"
+            "E-1020 (BAD_EXTRA_RANGE_NAME): An extra range name is configured with a name that does not correspond to any range: x_range_name='junk' [LinearAxis"
         )
 
         p = figure()
         p.extra_x_ranges['foo'] = Range1d()
         p.grid.x_range_name="junk"
         with mock.patch('bokeh.core.validation.check.log') as mock_logger:
-            check_integrity([p])
+            issues = check_integrity([p])
+            process_validation_issues(issues)
         assert mock_logger.error.call_count == 1
         assert mock_logger.error.call_args[0][0].startswith(
-            "E-1020 (BAD_EXTRA_RANGE_NAME): An extra range name is configued with a name that does not correspond to any range: x_range_name='junk' [Grid"
+            "E-1020 (BAD_EXTRA_RANGE_NAME): An extra range name is configured with a name that does not correspond to any range: x_range_name='junk' [Grid"
         )
         assert mock_logger.error.call_args[0][0].count("Grid") == 2
 
+    def test_bad_extra_range_only_immediate_refs(self) -> None:
         # test whether adding a figure (*and* it's extra ranges)
         # to another's references doesn't create a false positive
         p, dep = figure(), figure()
         dep.extra_x_ranges['foo'] = Range1d()
         dep.grid.x_range_name="foo"
+        p.grid[0].js_on_change("dimension", CustomJS(code = "", args = {"toto": dep.grid[0]}))
         with mock.patch('bokeh.core.validation.check.log') as mock_logger:
-            check_integrity([p])
+            issues = check_integrity([p])
+            process_validation_issues(issues)
         assert mock_logger.error.call_count == 0
 
 def test_plot_add_layout_raises_error_if_not_render() -> None:
@@ -262,6 +262,15 @@ def test_plot_with_no_title_specified_creates_an_empty_title() -> None:
     assert plot.title.text == ""
 
 
+def test_plot_if_title_is_converted_from_string_to_Title() -> None:
+    plot = Plot()
+    plot.title = "A title"
+    plot.title.text_color = "olive"
+    assert isinstance(plot.title, Title)
+    assert plot.title.text == "A title"
+    assert plot.title.text_color == "olive"
+
+
 def test_plot__scale_classmethod() -> None:
     assert isinstance(Plot._scale("auto"), LinearScale)
     assert isinstance(Plot._scale("linear"), LinearScale)
@@ -278,9 +287,8 @@ def test__check_required_scale_has_scales() -> None:
 
 
 def test__check_required_scale_missing_scales() -> None:
-    plot = Plot(x_scale=None, y_scale=None)
-    check = plot._check_required_scale()
-    assert check != []
+    with pytest.raises(ValueError):
+        Plot(x_scale=None, y_scale=None)
 
 
 def test__check_compatible_scale_and_ranges_compat_numeric() -> None:
@@ -288,7 +296,6 @@ def test__check_compatible_scale_and_ranges_compat_numeric() -> None:
     check = plot._check_compatible_scale_and_ranges()
     assert check == []
 
-
     plot = Plot(y_scale=LogScale(), y_range=DataRange1d())
     check = plot._check_compatible_scale_and_ranges()
     assert check == []
