@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -22,6 +24,9 @@ from itertools import repeat
 from flaky import flaky
 from tornado.ioloop import IOLoop
 
+# Bokeh imports
+from bokeh.util.serialization import make_id
+
 # Module under test
 from bokeh.util.tornado import _CallbackGroup # isort:skip
 
@@ -51,7 +56,7 @@ def run(loop):
         print("Keyboard interrupt")
 
 class LoopAndGroup:
-    def __init__(self, quit_after=None):
+    def __init__(self, quit_after=None) -> None:
         self.io_loop = IOLoop()
         self.io_loop.make_current()
         self.group = _CallbackGroup(self.io_loop)
@@ -78,7 +83,7 @@ class TestCallbackGroup:
         with (LoopAndGroup()) as ctx:
             func = _make_invocation_counter(ctx.io_loop)
             assert 0 == len(ctx.group._next_tick_callback_removers)
-            ctx.group.add_next_tick_callback(func)
+            ctx.group.add_next_tick_callback(callback=func, callback_id=make_id())
             assert 1 == len(ctx.group._next_tick_callback_removers)
         assert 1 == func.count()
         # check for leaks
@@ -89,7 +94,7 @@ class TestCallbackGroup:
         with (LoopAndGroup()) as ctx:
             func = _make_invocation_counter(ctx.io_loop)
             assert 0 == len(ctx.group._timeout_callback_removers)
-            ctx.group.add_timeout_callback(func, timeout_milliseconds=1)
+            ctx.group.add_timeout_callback(callback=func, timeout_milliseconds=1, callback_id=make_id())
             assert 1 == len(ctx.group._timeout_callback_removers)
         assert 1 == func.count()
         # check for leaks
@@ -100,7 +105,8 @@ class TestCallbackGroup:
         with (LoopAndGroup()) as ctx:
             func = _make_invocation_counter(ctx.io_loop, stop_after=5)
             assert 0 == len(ctx.group._periodic_callback_removers)
-            cb_id = ctx.group.add_periodic_callback(func, period_milliseconds=1)
+            cb_id = make_id()
+            ctx.group.add_periodic_callback(callback=func, period_milliseconds=1, callback_id=cb_id)
             assert 1 == len(ctx.group._periodic_callback_removers)
         assert 5 == func.count()
         # check for leaks... periodic doesn't self-remove though
@@ -112,7 +118,8 @@ class TestCallbackGroup:
     def test_next_tick_does_not_run_if_removed_immediately(self) -> None:
         with (LoopAndGroup(quit_after=15)) as ctx:
             func = _make_invocation_counter(ctx.io_loop)
-            cb_id = ctx.group.add_next_tick_callback(func)
+            cb_id = make_id()
+            ctx.group.add_next_tick_callback(callback=func, callback_id=cb_id)
             ctx.group.remove_next_tick_callback(cb_id)
         assert 0 == func.count()
 
@@ -120,7 +127,7 @@ class TestCallbackGroup:
     def test_timeout_does_not_run_if_removed_immediately(self) -> None:
         with (LoopAndGroup(quit_after=15)) as ctx:
             func = _make_invocation_counter(ctx.io_loop)
-            cb_id = ctx.group.add_timeout_callback(func, timeout_milliseconds=1)
+            cb_id = ctx.group.add_timeout_callback(callback=func, timeout_milliseconds=1, callback_id=make_id())
             ctx.group.remove_timeout_callback(cb_id)
         assert 0 == func.count()
 
@@ -128,7 +135,8 @@ class TestCallbackGroup:
     def test_periodic_does_not_run_if_removed_immediately(self) -> None:
         with (LoopAndGroup(quit_after=15)) as ctx:
             func = _make_invocation_counter(ctx.io_loop, stop_after=5)
-            cb_id = ctx.group.add_periodic_callback(func, period_milliseconds=1)
+            cb_id = make_id()
+            ctx.group.add_periodic_callback(callback=func, period_milliseconds=1, callback_id=cb_id)
             ctx.group.remove_periodic_callback(cb_id)
         assert 0 == func.count()
 
@@ -137,33 +145,33 @@ class TestCallbackGroup:
         with (LoopAndGroup()) as ctx:
             func = _make_invocation_counter(ctx.io_loop, stop_after=5)
             # we want the timeout and next_tick to run before the periodic
-            ctx.group.add_periodic_callback(func, period_milliseconds=2)
-            ctx.group.add_timeout_callback(func, timeout_milliseconds=1)
-            ctx.group.add_next_tick_callback(func)
+            ctx.group.add_periodic_callback(callback=func, period_milliseconds=2, callback_id=make_id())
+            ctx.group.add_timeout_callback(callback=func, timeout_milliseconds=1, callback_id=make_id())
+            ctx.group.add_next_tick_callback(callback=func, callback_id=make_id())
         assert 5 == func.count()
 
     @flaky(max_runs=10)
     def test_adding_next_tick_twice(self) -> None:
         with (LoopAndGroup()) as ctx:
             func = _make_invocation_counter(ctx.io_loop, stop_after=2)
-            ctx.group.add_next_tick_callback(func)
-            ctx.group.add_next_tick_callback(func)
+            ctx.group.add_next_tick_callback(callback=func, callback_id=make_id())
+            ctx.group.add_next_tick_callback(callback=func, callback_id=make_id())
         assert 2 == func.count()
 
     @flaky(max_runs=10)
     def test_adding_timeout_twice(self) -> None:
         with (LoopAndGroup()) as ctx:
             func = _make_invocation_counter(ctx.io_loop, stop_after=2)
-            ctx.group.add_timeout_callback(func, timeout_milliseconds=1)
-            ctx.group.add_timeout_callback(func, timeout_milliseconds=2)
+            ctx.group.add_timeout_callback(callback=func, timeout_milliseconds=1, callback_id=make_id())
+            ctx.group.add_timeout_callback(callback=func, timeout_milliseconds=2, callback_id=make_id())
         assert 2 == func.count()
 
     @flaky(max_runs=10)
     def test_adding_periodic_twice(self) -> None:
         with (LoopAndGroup()) as ctx:
             func = _make_invocation_counter(ctx.io_loop, stop_after=2)
-            ctx.group.add_periodic_callback(func, period_milliseconds=3)
-            ctx.group.add_periodic_callback(func, period_milliseconds=2)
+            ctx.group.add_periodic_callback(callback=func, period_milliseconds=3, callback_id=make_id())
+            ctx.group.add_periodic_callback(callback=func, period_milliseconds=2, callback_id=make_id())
         assert 2 == func.count()
 
     @flaky(max_runs=10)
@@ -172,19 +180,20 @@ class TestCallbackGroup:
             # add a callback that will remove all the others
             def remove_all():
                 ctx.group.remove_all_callbacks()
-            ctx.group.add_next_tick_callback(remove_all)
+            ctx.group.add_next_tick_callback(callback=remove_all, callback_id=make_id())
             # none of these should run
             func = _make_invocation_counter(ctx.io_loop, stop_after=5)
-            ctx.group.add_periodic_callback(func, period_milliseconds=2)
-            ctx.group.add_timeout_callback(func, timeout_milliseconds=1)
-            ctx.group.add_next_tick_callback(func)
+            ctx.group.add_periodic_callback(callback=func, period_milliseconds=2, callback_id=make_id())
+            ctx.group.add_timeout_callback(callback=func, timeout_milliseconds=1, callback_id=make_id())
+            ctx.group.add_next_tick_callback(callback=func, callback_id=make_id())
         assert 0 == func.count()
 
     @flaky(max_runs=10)
     def test_removing_next_tick_twice(self) -> None:
         with (LoopAndGroup(quit_after=15)) as ctx:
             func = _make_invocation_counter(ctx.io_loop)
-            cb_id = ctx.group.add_next_tick_callback(func)
+            cb_id = make_id()
+            ctx.group.add_next_tick_callback(callback=func, callback_id=cb_id)
             ctx.group.remove_next_tick_callback(cb_id)
             with pytest.raises(ValueError) as exc:
                 ctx.group.remove_next_tick_callback(cb_id)
@@ -195,7 +204,8 @@ class TestCallbackGroup:
     def test_removing_timeout_twice(self) -> None:
         with (LoopAndGroup(quit_after=15)) as ctx:
             func = _make_invocation_counter(ctx.io_loop)
-            cb_id = ctx.group.add_timeout_callback(func, timeout_milliseconds=1)
+            cb_id = make_id()
+            ctx.group.add_timeout_callback(callback=func, timeout_milliseconds=1, callback_id=cb_id)
             ctx.group.remove_timeout_callback(cb_id)
             with pytest.raises(ValueError) as exc:
                 ctx.group.remove_timeout_callback(cb_id)
@@ -206,7 +216,8 @@ class TestCallbackGroup:
     def test_removing_periodic_twice(self) -> None:
         with (LoopAndGroup(quit_after=15)) as ctx:
             func = _make_invocation_counter(ctx.io_loop, stop_after=5)
-            cb_id = ctx.group.add_periodic_callback(func, period_milliseconds=1)
+            cb_id = make_id()
+            ctx.group.add_periodic_callback(callback=func, period_milliseconds=1, callback_id=cb_id)
             ctx.group.remove_periodic_callback(cb_id)
             with pytest.raises(ValueError) as exc:
                 ctx.group.remove_periodic_callback(cb_id)
@@ -220,7 +231,9 @@ class TestCallbackGroup:
             n = 1000
             func = _make_invocation_counter(ctx.io_loop, stop_after=n)
             tpe = ThreadPoolExecutor(n)
-            list(tpe.map(ctx.group.add_next_tick_callback, repeat(func, n)))
+            def make_cb(cb):
+                return ctx.group.add_next_tick_callback(cb, callback_id=make_id())
+            list(tpe.map(make_cb, repeat(func, n)))
         assert n == func.count()
 
 #-----------------------------------------------------------------------------
