@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -35,7 +37,6 @@ ALL = (
     'STAMEN_TONER_BACKGROUND',
     'STAMEN_TONER_LABELS',
     'OSM',
-    'WIKIMEDIA',
     'ESRI_IMAGERY',
     'get_provider',
     'Vendors'
@@ -66,10 +67,6 @@ _OSM_URLS = {
     'OSM':                     'https://c.tile.openstreetmap.org/{Z}/{X}/{Y}.png'
 }
 
-_WIKIMEDIA_URLS = {
-    'WIKIMEDIA':               'https://maps.wikimedia.org/osm-intl/{Z}/{X}/{Y}@2x.png'
-}
-
 _ESRI_URLS = {
     'ESRI_IMAGERY':            'https://server.arcgisonline.com/ArcGIS/rest/services/World_Imagery/MapServer/tile/{Z}/{Y}/{X}.jpg'
 }
@@ -149,27 +146,6 @@ class Test_OsmProvider:
         p2 = bt.get_provider(getattr(bt, name))
         assert p1 is not p2
 
-@pytest.mark.parametrize('name', ['WIKIMEDIA'])
-class Test_WikimediaProvider:
-    def test_type(self, name) -> None:
-        p = getattr(bt, name)
-        assert isinstance(p, str)
-
-    def test_url(self, name) -> None:
-        p = bt.get_provider(getattr(bt, name))
-        assert p.url == _WIKIMEDIA_URLS[name]
-
-    def test_attribution(self, name) -> None:
-        p = bt.get_provider(getattr(bt, name))
-        assert p.attribution == (
-            '&copy; <a href="https://foundation.wikimedia.org/wiki/Maps_Terms_of_Use">Wikimedia Maps</a> contributors'
-        )
-
-    def test_copies(self, name) -> None:
-        p1 = bt.get_provider(getattr(bt, name))
-        p2 = bt.get_provider(getattr(bt, name))
-        assert p1 is not p2
-
 @pytest.mark.parametrize('name', ['ESRI_IMAGERY'])
 class Test_EsriProvider:
     def test_type(self, name) -> None:
@@ -195,7 +171,7 @@ class Test_EsriProvider:
 class Test_GetProvider:
     @pytest.mark.parametrize('name', ['CARTODBPOSITRON', 'CARTODBPOSITRON_RETINA', 'STAMEN_TERRAIN',
                                       'STAMEN_TERRAIN_RETINA', 'STAMEN_TONER', 'STAMEN_TONER_BACKGROUND',
-                                      'STAMEN_TONER_LABELS', 'OSM', 'WIKIMEDIA', 'ESRI_IMAGERY', ])
+                                      'STAMEN_TONER_LABELS', 'OSM', 'ESRI_IMAGERY', ])
     def test_get_provider(self, name) -> None:
         assert name in bt.Vendors
         enum_member = getattr(bt.Vendors, name)
@@ -220,6 +196,15 @@ class Test_GetProvider:
         with pytest.raises(ValueError):
             bt.get_provider("This is not a valid tile vendor")
 
+    def test_xyzservices(self) -> None:
+        xyzservices = pytest.importorskip("xyzservices")
+        provider_data = xyzservices.providers.CartoDB.Positron
+        provider = bt.get_provider(provider_data)
+        assert isinstance(provider, WMTSTileSource)
+        assert provider.url == provider_data.build_url(scale_factor="@2x")
+        assert provider.attribution == provider_data.html_attribution
+        assert provider.min_zoom == provider_data.get("min_zoom", 0)
+        assert provider.max_zoom == provider_data.get("max_zoom", 30)
 
 #-----------------------------------------------------------------------------
 # Dev API
